==> ugene_1.3.3+repack.orig.tar.gz: ugene-1.3.3/src/plugins/annotator/transl/english.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="en_US">
<defaultcodec></defaultcodec>
<defaultcodec></defaultcodec>
<context>
    <name>FindAnnotationCollocationsDialog</name>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="13"/>
        <source>dialog_tittle</source>
        <translation>Find groups of annotated regions</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="82"/>
        <source>region_size_label</source>
        <translation>Region size:</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="124"/>
        <source>search_button</source>
        <translation>Search</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="148"/>
        <source>save_annotations_button</source>
        <translation>Save regions as annotations..</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="155"/>
        <source>clear_results_button</source>
        <translation>Clear resutls</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="188"/>
        <source>cancel_button</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="44"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="49"/>
        <source>2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="168"/>
        <source>whole annotations</source>
        <translation>Annotation must fit into region</translation>
    </message>
</context>
<context>
    <name>GB2::AnnotatorPlugin</name>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="31"/>
        <source>dna_annotator_plugin</source>
        <translation>DNA Annotator</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="31"/>
        <source>dna_annotator_plugin_desc</source>
        <translation>This plugin contains routines to manipulate and search DNA sequence annotations</translation>
    </message>
</context>
<context>
    <name>GB2::AnnotatorViewContext</name>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="59"/>
        <source>find_annotation_collocations</source>
        <translation>Find annotated regions</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="89"/>
        <source>warning</source>
        <translation>Warning!</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="89"/>
        <source>no_annotations_found</source>
        <translation>No annotations found!</translation>
    </message>
</context>
<context>
    <name>GB2::CollocationSearchTask</name>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="312"/>
        <source>collocation_search_task</source>
        <translation>Search for annotated regions</translation>
    </message>
</context>
<context>
    <name>GB2::CollocationsDialogController</name>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="36"/>
        <source>click_to_add_new_annotation</source>
        <translation>&lt;&lt;click &apos;+&apos; button to add new annotation&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="69"/>
        <source>stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="69"/>
        <source>cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="75"/>
        <source>searching__found_%1_items_progress_%2</source>
        <translation>Searching... found %1 regions. Progress: %2%</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="77"/>
        <source>found_%1_items</source>
        <translation>Found %1 regions</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="79"/>
        <source>ready</source>
        <translation>Ready</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="79"/>
        <source>select_annotations</source>
        <translation>Select annotation names to search</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="98"/>
        <source>no_more_annotations_left</source>
        <translation>No annotations left</translation>
    </message>
</context>
<context>
    <name>GB2::GTest</name>
    <message>
        <location filename="../src/AnnotatorTests.cpp" line="82"/>
        <source>value not set %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/AnnotatorTests.cpp" line="60"/>
        <source>wrong value for %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/AnnotatorTests.cpp" line="90"/>
        <source>Unable to convert. Value wrong %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/AnnotatorTests.cpp" line="121"/>
        <source>context not found %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/AnnotatorTests.cpp" line="105"/>
        <source>container of object with type &quot;%1&quot; is empty</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/AnnotatorTests.cpp" line="110"/>
        <source>object with type &quot;%1&quot; not found</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/AnnotatorTests.cpp" line="116"/>
        <source>error can&apos;t cast to sequence from GObject</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/AnnotatorTests.cpp" line="138"/>
        <source>Expected and Actual lists of regions are different: %1 %2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/AnnotatorTests.cpp" line="143"/>
        <source>One of the expected regions not found in results</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::CollocationPrompter</name>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="111"/>
        <source> sequence from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="114"/>
        <source> set of annotations from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="121"/>
        <source>For each %1 and %2,</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="123"/>
        <source>For each %1%2,</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="138"/>
        <source> Annotations themselves may not span beyond the region.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="144"/>
        <source>%1 look if &lt;u&gt;%2&lt;/u&gt; annotations appear collocated within same region of length &lt;u&gt;%3&lt;/u&gt;.%4&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%5&lt;/u&gt;.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::CollocationWorker</name>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="200"/>
        <source>Found %1 collocations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="75"/>
        <source>Group annotations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="80"/>
        <source>Result annotation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="81"/>
        <source>Group of annotations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="82"/>
        <source>Region size</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="83"/>
        <source>Must fit into region</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="90"/>
        <source>Collocation search</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="51"/>
        <source>At least 2 annotations are required for collocation search.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="75"/>
        <source>Annotated regions containing found collocations.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="80"/>
        <source>Name of the result annotations to mark found collocations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="81"/>
        <source>A list of annotation names to search. Found regions will contain all the named annotations.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="82"/>
        <source>Effectively this is the maximum allowed distance between the interesting annotations in a group</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="83"/>
        <source>Whether the interesting annotations should entirely fit into the specified region to form a group</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="91"/>
        <source>Finds groups of specified annotations in each supplied set of annotations, stores found regions as annotations.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="73"/>
        <source>Input data</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="73"/>
        <source>An input sequence and a set of annotations to search in.</source>
        <translation></translation>
    </message>
</context>
</TS>

==> ugene_1.5.2+repack.orig.tar.gz: ugene-1.5.2/src/plugins/annotator/transl/english.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>FindAnnotationCollocationsDialog</name>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="13"/>
        <source>dialog_tittle</source>
        <translation>Find groups of annotated regions</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="82"/>
        <source>region_size_label</source>
        <translation>Region size:</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="124"/>
        <source>search_button</source>
        <translation>Search</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="148"/>
        <source>save_annotations_button</source>
        <translation>Save regions as annotations..</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="155"/>
        <source>clear_results_button</source>
        <translation>Clear resutls</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="188"/>
        <source>cancel_button</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="44"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="49"/>
        <source>2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindAnnotationCollocationsDialog.ui" line="168"/>
        <source>whole annotations</source>
        <translation>Annotation must fit into region</translation>
    </message>
</context>
<context>
    <name>GB2::AnnotatorPlugin</name>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="32"/>
        <source>dna_annotator_plugin</source>
        <translation>DNA Annotator</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="32"/>
        <source>dna_annotator_plugin_desc</source>
        <translation>This plugin contains routines to manipulate and search DNA sequence annotations</translation>
    </message>
</context>
<context>
    <name>GB2::AnnotatorViewContext</name>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="62"/>
        <source>find_annotation_collocations</source>
        <translation>Find annotated regions</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="80"/>
        <source>warning</source>
        <translation>Warning!</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="80"/>
        <source>no_annotations_found</source>
        <translation>No annotations found!</translation>
    </message>
</context>
<context>
    <name>GB2::CollocationSearchTask</name>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="287"/>
        <location filename="../src/CollocationsDialogController.cpp" line="311"/>
        <source>collocation_search_task</source>
        <translation>Search for annotated regions</translation>
    </message>
</context>
<context>
    <name>GB2::CollocationsDialogController</name>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="36"/>
        <source>click_to_add_new_annotation</source>
        <translation>&lt;&lt;click &apos;+&apos; button to add new annotation&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="69"/>
        <source>stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="69"/>
        <source>cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="75"/>
        <source>searching__found_%1_items_progress_%2</source>
        <translation>Searching... found %1 regions. Progress: %2%</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="77"/>
        <source>found_%1_items</source>
        <translation>Found %1 regions</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="79"/>
        <source>ready</source>
        <translation>Ready</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="79"/>
        <source>select_annotations</source>
        <translation>Select annotation names to search</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="98"/>
        <source>no_more_annotations_left</source>
        <translation>No annotations left</translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::CollocationPrompter</name>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="111"/>
        <source> sequence from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="114"/>
        <source> set of annotations from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="121"/>
        <source>For each %1 and %2,</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="123"/>
        <source>For each %1%2,</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="138"/>
        <source> Annotations themselves may not span beyond the region.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="142"/>
        <source>%1 look if &lt;u&gt;%2&lt;/u&gt; annotations appear collocated within same region of length &lt;u&gt;%3&lt;/u&gt;.%4&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%5&lt;/u&gt;.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::CollocationWorker</name>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="206"/>
        <source>Found %1 collocations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="75"/>
        <source>Group annotations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="80"/>
        <source>Result annotation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="81"/>
        <source>Group of annotations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="82"/>
        <source>Region size</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="83"/>
        <source>Must fit into region</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="90"/>
        <source>Collocation search</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="51"/>
        <source>At least 2 annotations are required for collocation search.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="75"/>
        <source>Annotated regions containing found collocations.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="80"/>
        <source>Name of the result annotations to mark found collocations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="81"/>
        <source>A list of annotation names to search. Found regions will contain all the named annotations.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="82"/>
        <source>Effectively this is the maximum allowed distance between the interesting annotations in a group</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="83"/>
        <source>Whether the interesting annotations should entirely fit into the specified region to form a group</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="91"/>
        <source>Finds groups of specified annotations in each supplied set of annotations, stores found regions as annotations.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="73"/>
        <source>Input data</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="73"/>
        <source>An input sequence and a set of annotations to search in.</source>
        <translation></translation>
    </message>
</context>
</TS>
